@@ -99,9 +99,9 @@ def ApplyExtinctionrules(HKL, Extinc, verbose=0):
         cond2 = (L) % 2 == 0
         cond = cond1 * cond2
         array_hkl = np.take(HKL, np.where(cond == True)[0], axis=0)
-    elif Extinc == "SG166":
-        cond = (-H + K + L) % 3 == 0
-        array_hkl = np.take(HKL, np.where(cond == True)[0], axis=0)
+    # elif Extinc == "SG166":
+    #     cond = (-H + K + L) % 3 == 0
+    #     array_hkl = np.take(HKL, np.where(cond == True)[0], axis=0)
     elif Extinc == "SG63":
         # general existence conditions for any h k l (take!)
         cond1 = (H + K) % 2 == 0
@@ -191,6 +191,111 @@ def ApplyExtinctionrules(HKL, Extinc, verbose=0):
 
         array_hkl = np.delete(array_hkl_3, np.where(condh00 == True)[0], axis=0)
 
+    elif Extinc == "SG225":  # SG 227 ( Sn alpha, magnetite)
+        #print("len start", len(H))
+        cond = ((H + K) % 2 == 0) * ((H + L) % 2 == 0) * ((K + L) % 2 == 0)
+
+        array_hkl_1 = np.take(HKL, np.where(cond == True)[0], axis=0)
+
+        H, K, L = array_hkl_1.T
+
+        cond0kl_1 = (H==0) * ((K) % 2 != 0) * ((L) % 2 != 0)
+        cond0kl_2 = (K==0)  * ((H) % 2 != 0) * ((L) % 2 != 0)
+        cond0kl_3 = (L==0)  * ((H) % 2 != 0) * ((K) % 2 != 0)
+
+        cond0kl = cond0kl_1 + cond0kl_2 + cond0kl_3
+
+        array_hkl_2 = np.delete(array_hkl_1, np.where(cond0kl == True)[0], axis=0)
+
+        H, K, L = array_hkl_2.T
+
+        condhhl_1 = (H == K) * ((H + L) % 2 != 0)
+        condhhl_2 = (K == L) * ((L + H) % 2 != 0)
+        condhhl_3 = (L == H) * ((H + K) % 2 != 0)
+
+        condhhl = condhhl_1 + condhhl_2 + condhhl_3
+
+        array_hkl_3 = np.delete(array_hkl_2, np.where(condhhl == True)[0], axis=0)
+
+        H, K, L = array_hkl_3.T
+
+        condh00_1 = (K == 0) * (L == 0) * (H % 2 != 0)
+        condh00_2 = (L == 0) * (H == 0) * (K % 2 != 0)
+        condh00_3 = (H == 0) * (K == 0) * (L % 2 != 0)
+
+        condh00 = condh00_1 + condh00_2 + condh00_3
+
+        array_hkl = np.delete(array_hkl_3, np.where(condh00 == True)[0], axis=0)
+        
+    elif Extinc == "SG82":  # SG 227 ( Sn alpha, magnetite)
+        #print("len start", len(H))
+        cond = (H + K + L) % 2 == 0
+        array_hkl_1 = np.take(HKL, np.where(cond == True)[0], axis=0)
+
+        H, K, L = array_hkl_1.T
+
+        cond0kl_1 = (H==0) * ((K + L) % 2 != 0)
+        cond0kl_2 = (K==0) * ((H + L) % 2 != 0)
+        cond0kl_3 = (L==0) * ((H + K) % 2 != 0)
+
+        cond0kl = cond0kl_1 + cond0kl_2 + cond0kl_3
+
+        array_hkl_2 = np.delete(array_hkl_1, np.where(cond0kl == True)[0], axis=0)
+
+        H, K, L = array_hkl_2.T
+
+        condhhl_1 = (H == K) * ((H + L) % 2 != 0)
+        condhhl_2 = (K == L) * ((L + H) % 2 != 0)
+        condhhl_3 = (L == H) * ((H + K) % 2 != 0)
+
+        condhhl = condhhl_1 + condhhl_2 + condhhl_3
+
+        array_hkl_3 = np.delete(array_hkl_2, np.where(condhhl == True)[0], axis=0)
+
+        H, K, L = array_hkl_3.T
+
+        condh00_1 = (K == 0) * (L == 0) * (H % 2 != 0)
+        condh00_2 = (L == 0) * (H == 0) * (K % 2 != 0)
+        condh00_3 = (H == 0) * (K == 0) * (L % 2 != 0)
+
+        condh00 = condh00_1 + condh00_2 + condh00_3
+
+        array_hkl = np.delete(array_hkl_3, np.where(condh00 == True)[0], axis=0)
+
+    elif Extinc == "SG166":  # SG 227 ( Sn alpha, magnetite)
+        #print("len start", len(H))
+        cond = (-H + K + L) % 3 == 0
+        array_hkl_1 = np.take(HKL, np.where(cond == True)[0], axis=0)
+
+        H, K, L = array_hkl_1.T
+
+        cond0kl_1 = (H==0) * ((K + L) % 3 != 0)
+        cond0kl_2 = (K==0) * ((H - L) % 3 != 0)
+        cond0kl_3 = (L==0) * ((H - K) % 3 != 0)
+
+        cond0kl = cond0kl_1 + cond0kl_2 + cond0kl_3
+
+        array_hkl_2 = np.delete(array_hkl_1, np.where(cond0kl == True)[0], axis=0)
+
+        H, K, L = array_hkl_2.T
+
+        condhhl_1 = (H == K) * ( L % 3 != 0)
+        condhhl_2 = (H == -K) * ((H + L) % 3 != 0)
+        condhhl_3 = (H == -K) * (K == 0) * (H % 3 != 0)
+        
+        condhhl = condhhl_1 + condhhl_2 + condhhl_3
+        array_hkl_3 = np.delete(array_hkl_2, np.where(condhhl == True)[0], axis=0)
+
+        H, K, L = array_hkl_3.T
+
+        condh00_1 = (K == 0) * (L == 0) * (H % 3 != 0)
+        condh00_2 = (L == 0) * (H == 0) * (K % 3 != 0)
+        condh00_3 = (H == 0) * (K == 0) * (L % 3 != 0)
+
+        condh00 = condh00_1 + condh00_2 + condh00_3
+
+        array_hkl = np.delete(array_hkl_3, np.where(condh00 == True)[0], axis=0)
+        
     elif Extinc == "Al2O3_rhombo":
         cond1 = (H - K) == 0
         cond2 = (L) % 2 == 0
